<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>AppendDialog</name>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="432"/>
        <source>Add files to the current archive</source>
        <translation>Fájlok hozzáadása az aktuális archívumhoz</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="437"/>
        <source>Use password</source>
        <translation>Jelszó használata</translation>
    </message>
</context>
<context>
    <name>CalculateSizeThread</name>
    <message>
        <location filename="../src/source/common/calculatesizethread.cpp" line="68"/>
        <location filename="../src/source/common/calculatesizethread.cpp" line="136"/>
        <source>The original file of %1 does not exist, please check and try again</source>
        <translation>A %1 eredeti fájl nem létezik, kérjük ellenőrizze, és próbálja újra</translation>
    </message>
    <message>
        <location filename="../src/source/common/calculatesizethread.cpp" line="70"/>
        <location filename="../src/source/common/calculatesizethread.cpp" line="138"/>
        <source>%1 does not exist on the disk, please check and try again</source>
        <translation>A %1 nem létezik a lemezen, kérjük ellenőrizze és próbálja újra</translation>
    </message>
    <message>
        <location filename="../src/source/common/calculatesizethread.cpp" line="79"/>
        <location filename="../src/source/common/calculatesizethread.cpp" line="147"/>
        <source>You do not have permission to compress %1</source>
        <translation>Nincs engedélye a %1 tömörítésére</translation>
    </message>
</context>
<context>
    <name>CommentProgressDialog</name>
    <message>
        <location filename="../src/source/dialog/progressdialog.cpp" line="234"/>
        <source>Updating the comment...</source>
        <translation>Hozzászólások frissítése...</translation>
    </message>
</context>
<context>
    <name>CompressPage</name>
    <message>
        <location filename="../src/source/page/compresspage.cpp" line="76"/>
        <source>Next</source>
        <translation>Következő</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresspage.cpp" line="117"/>
        <source>Please add files</source>
        <translation>Kérjük adjon hozzá fájlokat</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresspage.cpp" line="117"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>CompressSettingPage</name>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="143"/>
        <location filename="../src/source/page/compresssettingpage.cpp" line="226"/>
        <source>New Archive</source>
        <translation>Új archívum</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="204"/>
        <source>Advanced Options</source>
        <translation>Haladó beállítások</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="208"/>
        <source>Compression method</source>
        <translation>Tömörítési módszer</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="211"/>
        <source>Encrypt the archive</source>
        <translation>Archívum titkosítása</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="213"/>
        <source>CPU threads</source>
        <translation>Processzor szálak</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="215"/>
        <source>Encrypt the file list too</source>
        <translation>Titkosítsa a fájllistát is</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="217"/>
        <source>Split to volumes</source>
        <translation>Kötetekre darabolás</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="219"/>
        <source>Comment</source>
        <translation>Hozzászólás</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="221"/>
        <source>Compress</source>
        <comment>button</comment>
        <translation>Tömörítés</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="240"/>
        <source>Store</source>
        <translation>Áruház</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="240"/>
        <source>Fastest</source>
        <translation>Leggyorsabb</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="240"/>
        <source>Fast</source>
        <translation>Gyors</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="240"/>
        <source>Normal</source>
        <translation>Normál</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="240"/>
        <source>Good</source>
        <translation>Jó</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="240"/>
        <source>Best</source>
        <translation>Legjobb</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="247"/>
        <source>Single thread</source>
        <translation>Egy szál</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="247"/>
        <source>2 threads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="247"/>
        <source>4 threads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="247"/>
        <source>8 threads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="257"/>
        <source>Support zip, 7z type only</source>
        <translation>Zip formátum támogatása ,csak a 7z típusé</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="260"/>
        <source>Support 7z type only</source>
        <translation>Csak 7z formátum támogatása</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="272"/>
        <source>Enter up to %1 characters</source>
        <translation>Adjon meg legfeljebb %1 karaktert</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="293"/>
        <source>Name</source>
        <translation>Név</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="294"/>
        <source>Save to</source>
        <translation>Mentés ide</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="483"/>
        <source>Invalid file name</source>
        <translation>Érvénytelen fájlnév</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="489"/>
        <source>Please enter the path</source>
        <translation>Kérjük adja meg az elérési útvonalat</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="494"/>
        <source>The path does not exist, please retry</source>
        <translation>Az elérési útvonal nem létezik, kérjük próbálja újra</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="499"/>
        <source>You do not have permission to save files here, please change and retry</source>
        <translation>Nincs engedélye fájlok ide mentésére, kérjük módosítsa és próbálja újra</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="507"/>
        <source>Too many volumes, please change and retry</source>
        <translation>Túl sok kötet, kérjük változtasson és próbálkozzon újra</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="516"/>
        <location filename="../src/source/page/compresssettingpage.cpp" line="544"/>
        <source>%1 does not exist on the disk, please check and try again</source>
        <translation>A %1 nem létezik a lemezen, kérjük ellenőrizze és próbálja újra</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="522"/>
        <location filename="../src/source/page/compresssettingpage.cpp" line="551"/>
        <source>You do not have permission to compress %1</source>
        <translation>Nincs engedélye a %1 tömörítésére</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="542"/>
        <source>The original file of %1 does not exist, please check and try again</source>
        <translation>A %1 eredeti fájl nem létezik, kérjük ellenőrizze, és próbálja újra</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="577"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="783"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Mégsem</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="783"/>
        <source>Replace</source>
        <comment>button</comment>
        <translation>Csere</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="691"/>
        <source>Total size: %1</source>
        <translation>Teljes méret: %1</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="711"/>
        <source>The name is the same as that of the compressed archive, please use another one</source>
        <translation>A név megegyezik a tömörített archívum nevével, kérjük használjon másikat</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="719"/>
        <source>The password for ZIP volumes cannot be in Chinese</source>
        <translation>A ZIP kötetek jelszava nem lehet kínai</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="783"/>
        <source>Another file with the same name already exists, replace it?</source>
        <translation>Már létezik egy ugyanilyen nevű fájl, lecseréli?</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="823"/>
        <source>Only Chinese and English characters and some symbols are supported</source>
        <translation>Csak a kínai, és az angol karakterek, valamint néhány szimbólum támogatott </translation>
    </message>
</context>
<context>
    <name>CompressView</name>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="284"/>
        <source>Open</source>
        <translation>Megnyitás</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="298"/>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="301"/>
        <source>Open with</source>
        <translation>Megnyitás ezzel</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="305"/>
        <location filename="../src/source/tree/compressview.cpp" line="407"/>
        <source>Select default program</source>
        <translation>Alapértelmezett program választása</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="348"/>
        <source>It will permanently delete the file(s). Are you sure you want to continue?</source>
        <translation>A fájl(ok) véglegesen törlésre kerülnek. Biztos benne, hogy folytatni akarja?</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="348"/>
        <location filename="../src/source/tree/compressview.cpp" line="381"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Mégsem</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="348"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Megerősítés</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="382"/>
        <source>Add</source>
        <comment>button</comment>
        <translation>Hozzáadás</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="380"/>
        <source>Do you want to add the archive to the list or open it in new window?</source>
        <translation>Hozzá szeretné adni az archívumot a listához, vagy új ablakban szeretné megnyitni?</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="383"/>
        <source>Open in new window</source>
        <translation>Megnyitás új ablakban</translation>
    </message>
</context>
<context>
    <name>ConvertDialog</name>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="306"/>
        <source>Changes to archives in this file type are not supported. Please convert the archive format to save the changes.</source>
        <translation>Az ilyen típusú archívumok módosításai nem támogatottak. A változások mentéséhez kérjük alakítsa át az archívum formátumát.</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="314"/>
        <source>Convert the format to:</source>
        <translation>Konvertálja a formátumot a következőre:</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="338"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Mégsem</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="339"/>
        <source>Convert</source>
        <comment>button</comment>
        <translation>Konvertálás</translation>
    </message>
</context>
<context>
    <name>DataModel</name>
    <message>
        <location filename="../src/source/tree/datamodel.cpp" line="70"/>
        <source>item(s)</source>
        <translation>elem(ek)</translation>
    </message>
</context>
<context>
    <name>FailurePage</name>
    <message>
        <location filename="../src/source/page/failurepage.cpp" line="87"/>
        <source>Extraction failed</source>
        <comment>解压失败</comment>
        <translation>A kicsomagolás sikertelen</translation>
    </message>
    <message>
        <location filename="../src/source/page/failurepage.cpp" line="100"/>
        <source>Damaged file, unable to extract</source>
        <translation>Sérült fájl, a kicsomagolás sikertelen</translation>
    </message>
    <message>
        <location filename="../src/source/page/failurepage.cpp" line="105"/>
        <source>Retry</source>
        <comment>button</comment>
        <translation>Újra</translation>
    </message>
    <message>
        <location filename="../src/source/page/failurepage.cpp" line="108"/>
        <source>Back</source>
        <translation>Vissza</translation>
    </message>
</context>
<context>
    <name>HomePage</name>
    <message>
        <location filename="../src/source/page/homepage.cpp" line="56"/>
        <source>Drag file or folder here</source>
        <translation>Húzza ide a fájlokat és / vagy a mappákat</translation>
    </message>
    <message>
        <location filename="../src/source/page/homepage.cpp" line="58"/>
        <source>Select File</source>
        <translation>Fájl kiválasztása</translation>
    </message>
</context>
<context>
    <name>LoadCorruptQuery</name>
    <message>
        <location filename="../3rdparty/interface/queries.cpp" line="525"/>
        <source>The archive is damaged</source>
        <translation>Az archívum sérült</translation>
    </message>
    <message>
        <location filename="../3rdparty/interface/queries.cpp" line="528"/>
        <source>Open as read-only</source>
        <translation>Megnyitás csak olvasható módban</translation>
    </message>
    <message>
        <location filename="../3rdparty/interface/queries.cpp" line="529"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Mégsem</translation>
    </message>
</context>
<context>
    <name>LoadingPage</name>
    <message>
        <location filename="../src/source/page/loadingpage.cpp" line="65"/>
        <source>Loading, please wait...</source>
        <translation>Betöltés, kérjük várjon...</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../src/main.cpp" line="60"/>
        <location filename="../src/main.cpp" line="61"/>
        <source>Archive Manager</source>
        <translation>Archívumkezelő</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="62"/>
        <source>Archive Manager is a fast and lightweight application for creating and extracting archives.</source>
        <translation>Az Archívumkezelő egy gyors és kis erőforrás igényű alkalmazás, tömörített fájlok létrehozásához és kibontásához.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="172"/>
        <location filename="../src/source/mainwindow.cpp" line="191"/>
        <location filename="../src/source/mainwindow.cpp" line="440"/>
        <source>Open file</source>
        <translation>Fájl megnyitása</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="173"/>
        <source>Settings</source>
        <translation>Beállítások</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="294"/>
        <location filename="../src/source/mainwindow.cpp" line="304"/>
        <source>Create New Archive</source>
        <translation>Új archívum létrehozása</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="345"/>
        <source>Converting</source>
        <translation>Konvertálás</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="352"/>
        <source>Updating comments</source>
        <translation>Hozzászólások frissítése</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="523"/>
        <location filename="../src/source/mainwindow.cpp" line="2068"/>
        <location filename="../src/source/mainwindow.cpp" line="2090"/>
        <location filename="../src/source/mainwindow.cpp" line="2115"/>
        <source>Plugin error</source>
        <translation>Bővítmény hiba</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1302"/>
        <source>Adding successful</source>
        <translation>A hozzáadás sikeres</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1334"/>
        <location filename="../src/source/mainwindow.cpp" line="2139"/>
        <source>No data in it</source>
        <translation>Nem tartalmaz adatot</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1522"/>
        <source>Adding canceled</source>
        <translation>A hozzáadás megszakítva</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1620"/>
        <source>Adding failed</source>
        <translation>A hozzáadás sikertelen</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1673"/>
        <source>Extraction failed: the file name is too long</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1700"/>
        <location filename="../src/source/mainwindow.cpp" line="2135"/>
        <source>Failed to create &quot;%1&quot;</source>
        <translation>A &quot;%1&quot; létrehozása sikertelen</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1822"/>
        <source>Open failed: the file name is too long</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2041"/>
        <source>Compression successful</source>
        <translation>A tömörítés sikeres</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2047"/>
        <source>The file name is too long, so the first 60 characters have been intercepted as the file name.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2076"/>
        <location filename="../src/source/mainwindow.cpp" line="2143"/>
        <source>Insufficient disk space</source>
        <translation>Nincs elég lemezterület</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2102"/>
        <location filename="../src/source/mainwindow.cpp" line="2123"/>
        <source>Some volumes are missing</source>
        <translation>Néhány kötet hiányzik</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2127"/>
        <source>Wrong password, please retry</source>
        <translation>Érvénytelen jelszó, kérjük próbálja újra</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2131"/>
        <location filename="../src/source/mainwindow.cpp" line="2155"/>
        <source>The file name is too long. Keep the name within 60 characters please.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2152"/>
        <source>Conversion failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2290"/>
        <source>Select file</source>
        <translation>Fájl kiválasztása</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3102"/>
        <source>Enter up to %1 characters</source>
        <translation>Adjon meg legfeljebb %1 karaktert</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="196"/>
        <location filename="../src/source/mainwindow.cpp" line="2978"/>
        <source>File info</source>
        <translation>Fájl információ</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1411"/>
        <source>Do you want to delete the archive?</source>
        <translation>Biztos, hogy törli az archívumot?</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="553"/>
        <source>%1 was changed on the disk, please import it again.</source>
        <translation>A %1 megváltozott a lemezen, kérjük importálja újra.</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="73"/>
        <source>Archive Manager</source>
        <translation>Archívumkezelő</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="129"/>
        <source>You do not have permission to save files here, please change and retry</source>
        <translation>Nincs engedélye fájlok ide mentésére, kérjük módosítsa és próbálja újra</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="317"/>
        <source>Adding files to %1</source>
        <translation>Fájlok hozzáadása a %1 fájlhoz</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="324"/>
        <source>Compressing</source>
        <translation>Tömörítés</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="331"/>
        <source>Extracting</source>
        <translation>Kicsomagolás</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="338"/>
        <source>Deleting</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="443"/>
        <source>Back</source>
        <translation>Vissza</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="513"/>
        <location filename="../src/source/mainwindow.cpp" line="2802"/>
        <source>Loading, please wait...</source>
        <translation>Betöltés, kérjük várjon...</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="586"/>
        <source>Are you sure you want to stop the ongoing task?</source>
        <translation>Biztosan le akarja állítani a folyamatban lévő feladatot?</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1308"/>
        <location filename="../src/source/mainwindow.cpp" line="1434"/>
        <source>Updating, please wait...</source>
        <translation>Frissítés, kérjük várjon...</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1695"/>
        <source>File name too long</source>
        <translation>A fájlnév túl hosszú</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2072"/>
        <source>Failed to create file</source>
        <translation>A fájl létrehozása sikertelen</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2065"/>
        <source>Compression failed</source>
        <translation>A tömörítés sikertelen</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2400"/>
        <source>Replace</source>
        <comment>button</comment>
        <translation>Csere</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2464"/>
        <source>Find directory</source>
        <translation>Mappa keresése</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2087"/>
        <source>Open failed</source>
        <translation>A megnyitás sikertelen</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1616"/>
        <location filename="../src/source/mainwindow.cpp" line="1690"/>
        <location filename="../src/source/mainwindow.cpp" line="1765"/>
        <location filename="../src/source/mainwindow.cpp" line="1820"/>
        <location filename="../src/source/mainwindow.cpp" line="2098"/>
        <source>Wrong password</source>
        <translation>Érvénytelen jelszó</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="626"/>
        <location filename="../src/source/mainwindow.cpp" line="659"/>
        <source>The file format is not supported by Archive Manager</source>
        <translation>Ez a fájl formátum nem támogatott az Archívumkezelő által</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="129"/>
        <location filename="../src/source/mainwindow.cpp" line="461"/>
        <location filename="../src/source/mainwindow.cpp" line="523"/>
        <location filename="../src/source/mainwindow.cpp" line="556"/>
        <location filename="../src/source/mainwindow.cpp" line="611"/>
        <location filename="../src/source/mainwindow.cpp" line="617"/>
        <location filename="../src/source/mainwindow.cpp" line="626"/>
        <location filename="../src/source/mainwindow.cpp" line="666"/>
        <location filename="../src/source/mainwindow.cpp" line="1334"/>
        <location filename="../src/source/mainwindow.cpp" line="2271"/>
        <location filename="../src/source/mainwindow.cpp" line="2558"/>
        <location filename="../src/source/mainwindow.cpp" line="2722"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="461"/>
        <location filename="../src/source/mainwindow.cpp" line="617"/>
        <source>You do not have permission to load %1</source>
        <translation>Nincs engedélye a %1 betöltésére</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="586"/>
        <location filename="../src/source/mainwindow.cpp" line="1411"/>
        <location filename="../src/source/mainwindow.cpp" line="2400"/>
        <location filename="../src/source/mainwindow.cpp" line="2824"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Mégsem</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="586"/>
        <location filename="../src/source/mainwindow.cpp" line="1411"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Megerősítés</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="611"/>
        <source>No such file or directory</source>
        <translation>Nem létezik ilyen fájl, vagy könyvtár</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1350"/>
        <source>Extraction successful</source>
        <comment>提取成功</comment>
        <translation>A kicsomagolás sikeres</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1543"/>
        <source>Extraction canceled</source>
        <comment>取消提取</comment>
        <translation>A kicsomagolás megszakítva</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1685"/>
        <location filename="../src/source/mainwindow.cpp" line="1760"/>
        <location filename="../src/source/mainwindow.cpp" line="2094"/>
        <location filename="../src/source/mainwindow.cpp" line="2119"/>
        <source>The archive is damaged</source>
        <translation>Az archívum sérült</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2045"/>
        <source>Extraction successful</source>
        <comment>解压成功</comment>
        <translation>A kicsomagolás sikeres</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2051"/>
        <source>Conversion successful</source>
        <translation>A konvertálás sikeres</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2112"/>
        <source>Extraction failed</source>
        <comment>解压失败</comment>
        <translation>A kicsomagolás sikertelen</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2282"/>
        <source>Close</source>
        <translation>Bezárás</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2286"/>
        <source>Help</source>
        <translation>Segítség</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2294"/>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2302"/>
        <source>Display shortcuts</source>
        <translation>Gyorsbillentyűk megjelenítése</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2314"/>
        <source>Shortcuts</source>
        <translation>Gyorsbillentyűk</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2392"/>
        <source>The name is the same as that of the compressed archive, please use another one</source>
        <translation>A név megegyezik a tömörített archívum nevével, kérjük használjon másikat</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2400"/>
        <source>Another file with the same name already exists, replace it?</source>
        <translation>Már létezik egy ugyanilyen nevű fájl, lecseréli?</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2543"/>
        <source>You cannot add the archive to itself</source>
        <translation>Az archívum nem adható hozzá önmagához</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2558"/>
        <source>You cannot add files to archives in this file type</source>
        <translation>Nem adhat hozzá fájlokat az ilyen típusú archívumokhoz</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2824"/>
        <source>Update</source>
        <comment>button</comment>
        <translation>Frissítés</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3002"/>
        <source>Basic info</source>
        <translation>Alapvető információ</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3018"/>
        <source>Size</source>
        <translation>Méret</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3019"/>
        <source>Type</source>
        <translation>Típus</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3020"/>
        <source>Location</source>
        <translation>Hely</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3021"/>
        <source>Time created</source>
        <translation>Létrehozás ideje</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3022"/>
        <source>Time accessed</source>
        <translation>Hozzáférés ideje</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3023"/>
        <source>Time modified</source>
        <translation>Módosítás időpontja</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3033"/>
        <source>Archive</source>
        <translation>Archívum</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3064"/>
        <source>Comment</source>
        <translation>Hozzászólás</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="656"/>
        <source>Please check the file association type in the settings of Archive Manager</source>
        <translation>Kérjük ellenőrizze a fájl társítási típusát az Archívumkezelő beállításaiban</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2271"/>
        <source>The archive was changed on the disk, please import it again.</source>
        <translation>Az archívum megváltozott a lemezen, kérjük importálja újra.</translation>
    </message>
</context>
<context>
    <name>MimeTypeDisplayManager</name>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="46"/>
        <source>Directory</source>
        <translation>Mappa</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="47"/>
        <source>Application</source>
        <translation>Alkalmazás</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="48"/>
        <source>Video</source>
        <translation>Videó</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="49"/>
        <source>Audio</source>
        <translation>Audió</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="50"/>
        <source>Image</source>
        <translation>Kép</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="51"/>
        <source>Archive</source>
        <translation>Archívum</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="53"/>
        <source>Executable</source>
        <translation>Futtatható állomány</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="52"/>
        <source>Document</source>
        <translation>Dokumentum</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="54"/>
        <source>Backup file</source>
        <translation>Biztonsági mentés fájlja</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="55"/>
        <source>Unknown</source>
        <translation>Ismeretlen</translation>
    </message>
</context>
<context>
    <name>OpenWithDialog</name>
    <message>
        <location filename="../src/source/dialog/openwithdialog/openwithdialog.cpp" line="280"/>
        <source>Open with</source>
        <translation>Megnyitás ezzel</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/openwithdialog/openwithdialog.cpp" line="300"/>
        <source>Add other programs</source>
        <translation>Más programok hozzáadása</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/openwithdialog/openwithdialog.cpp" line="301"/>
        <source>Set as default</source>
        <translation>Beállítás alapértelmezettként</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/openwithdialog/openwithdialog.cpp" line="303"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Mégsem</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/openwithdialog/openwithdialog.cpp" line="304"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Megerősítés</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/openwithdialog/openwithdialog.cpp" line="308"/>
        <source>Recommended Applications</source>
        <translation>Javasolt alkalmazások</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/openwithdialog/openwithdialog.cpp" line="310"/>
        <source>Other Applications</source>
        <translation>Egyéb alkalmazások</translation>
    </message>
</context>
<context>
    <name>PasswordNeededQuery</name>
    <message>
        <location filename="../3rdparty/interface/queries.cpp" line="394"/>
        <source>Encrypted file, please enter the password</source>
        <translation>Titkosított fájl, kérjük adja meg a jelszót</translation>
    </message>
</context>
<context>
    <name>PreviousLabel</name>
    <message>
        <location filename="../src/source/tree/treeheaderview.cpp" line="52"/>
        <source>Current path:</source>
        <translation>Jelenlegi útvonal:</translation>
    </message>
    <message>
        <location filename="../src/source/tree/treeheaderview.cpp" line="60"/>
        <source>Back to: %1</source>
        <translation>Vissza ide: %1</translation>
    </message>
</context>
<context>
    <name>ProgressDialog</name>
    <message>
        <location filename="../src/source/dialog/progressdialog.cpp" line="52"/>
        <source>%1 task(s) in progress</source>
        <translation>%1 feladat(ok) végrehajtása folyamatban</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/progressdialog.cpp" line="59"/>
        <location filename="../src/source/dialog/progressdialog.cpp" line="102"/>
        <source>Task</source>
        <translation>Feladat</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/progressdialog.cpp" line="65"/>
        <location filename="../src/source/dialog/progressdialog.cpp" line="113"/>
        <source>Extracting</source>
        <translation>Kicsomagolás</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/progressdialog.cpp" line="192"/>
        <source>Are you sure you want to stop the extraction?</source>
        <translation>Biztosan meg akarja szakítani a kicsomagolást?</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/progressdialog.cpp" line="194"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Mégsem</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/progressdialog.cpp" line="194"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Megerősítés</translation>
    </message>
</context>
<context>
    <name>ProgressPage</name>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="52"/>
        <location filename="../src/source/page/progresspage.cpp" line="314"/>
        <location filename="../src/source/page/progresspage.cpp" line="317"/>
        <location filename="../src/source/page/progresspage.cpp" line="320"/>
        <source>Speed</source>
        <comment>compress</comment>
        <translation>Sebesség</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="52"/>
        <location filename="../src/source/page/progresspage.cpp" line="54"/>
        <location filename="../src/source/page/progresspage.cpp" line="56"/>
        <location filename="../src/source/page/progresspage.cpp" line="60"/>
        <location filename="../src/source/page/progresspage.cpp" line="63"/>
        <location filename="../src/source/page/progresspage.cpp" line="149"/>
        <source>Calculating...</source>
        <translation>Számítás...</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="54"/>
        <location filename="../src/source/page/progresspage.cpp" line="324"/>
        <location filename="../src/source/page/progresspage.cpp" line="326"/>
        <source>Speed</source>
        <comment>delete</comment>
        <translation>Sebesség</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="56"/>
        <location filename="../src/source/page/progresspage.cpp" line="338"/>
        <location filename="../src/source/page/progresspage.cpp" line="340"/>
        <location filename="../src/source/page/progresspage.cpp" line="342"/>
        <source>Speed</source>
        <comment>convert</comment>
        <translation>Sebesség</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="60"/>
        <location filename="../src/source/page/progresspage.cpp" line="330"/>
        <location filename="../src/source/page/progresspage.cpp" line="332"/>
        <location filename="../src/source/page/progresspage.cpp" line="334"/>
        <source>Speed</source>
        <comment>uncompress</comment>
        <translation>Sebesség</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="63"/>
        <location filename="../src/source/page/progresspage.cpp" line="310"/>
        <source>Time left</source>
        <translation>Hátralévő idő</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="122"/>
        <source>Compressing</source>
        <translation>Tömörítés</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="124"/>
        <source>Deleting</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="126"/>
        <source>Converting</source>
        <translation>Konvertálás</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="128"/>
        <location filename="../src/source/page/progresspage.cpp" line="147"/>
        <source>Updating the comment...</source>
        <translation>Hozzászólások frissítése...</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="130"/>
        <source>Extracting</source>
        <translation>Kicsomagolás</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="141"/>
        <location filename="../src/source/page/progresspage.cpp" line="178"/>
        <location filename="../src/source/page/progresspage.cpp" line="358"/>
        <source>Pause</source>
        <comment>button</comment>
        <translation>Szüneteltetés</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="177"/>
        <location filename="../src/source/page/progresspage.cpp" line="387"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Mégsem</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="354"/>
        <source>Continue</source>
        <comment>button</comment>
        <translation>Folytatás</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="387"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Megerősítés</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="376"/>
        <source>Are you sure you want to stop the decompression?</source>
        <translation>Biztosan le szeretné állítani a kicsomagolást?</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="378"/>
        <source>Are you sure you want to stop the deletion?</source>
        <translation>Biztosan meg akarja szakítani a törlést?</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="374"/>
        <location filename="../src/source/page/progresspage.cpp" line="380"/>
        <source>Are you sure you want to stop the compression?</source>
        <translation>Biztosan le szeretné állítani a tömörítést?</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="382"/>
        <source>Are you sure you want to stop the conversion?</source>
        <translation>Biztosan meg akarja szakítani a konvertálást?</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/source/tree/datamodel.h" line="71"/>
        <source>Name</source>
        <translation>Név</translation>
    </message>
    <message>
        <location filename="../src/source/tree/datamodel.h" line="71"/>
        <source>Time modified</source>
        <translation>Módosítás időpontja</translation>
    </message>
    <message>
        <location filename="../src/source/tree/datamodel.h" line="71"/>
        <source>Type</source>
        <translation>Típus</translation>
    </message>
    <message>
        <location filename="../src/source/tree/datamodel.h" line="71"/>
        <source>Size</source>
        <translation>Méret</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2821"/>
        <source>%1 changed. Do you want to save changes to the archive?</source>
        <translation>A %1 megváltozott. El akarja menteni az archívum módosításait?</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settings_translation.cpp" line="26"/>
        <source>General</source>
        <translation>Általános</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settings_translation.cpp" line="27"/>
        <source>Extraction</source>
        <translation>Kicsomagolás</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settings_translation.cpp" line="28"/>
        <source>Auto create a folder for multiple extracted files</source>
        <translation>Automatikusan hozzon létre egy mappát a többszörösen kibontott fájlok számára</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settings_translation.cpp" line="29"/>
        <source>Show extracted files when completed</source>
        <translation>A kibontott fájlok megjelenítése befejezés után</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settings_translation.cpp" line="30"/>
        <source>File Management</source>
        <translation>Fájlkezelés</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settings_translation.cpp" line="31"/>
        <source>Delete files after compression</source>
        <translation>A fájlok törlése a tömörítés után</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settings_translation.cpp" line="32"/>
        <source>Files Associated</source>
        <translation>Társított fájltípusok</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settings_translation.cpp" line="33"/>
        <source>File Type</source>
        <translation>Fájltípus</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="202"/>
        <location filename="../src/source/dialog/popupdialog.cpp" line="208"/>
        <location filename="../3rdparty/interface/queries.cpp" line="244"/>
        <source>Skip</source>
        <comment>button</comment>
        <translation>Kihagyás</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="203"/>
        <source>Merge</source>
        <comment>button</comment>
        <translation>Összevonás</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="206"/>
        <location filename="../3rdparty/interface/queries.cpp" line="221"/>
        <source>Another file with the same name already exists, replace it?</source>
        <translation>Már létezik egy ugyanilyen nevű fájl, lecseréli?</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="209"/>
        <location filename="../3rdparty/interface/queries.cpp" line="245"/>
        <source>Replace</source>
        <comment>button</comment>
        <translation>Csere</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="477"/>
        <location filename="../3rdparty/interface/queries.cpp" line="405"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Mégsem</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="478"/>
        <location filename="../3rdparty/interface/queries.cpp" line="406"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="200"/>
        <source>Another folder with the same name already exists, replace it?</source>
        <translation>Már létezik egy ugyanilyen nevű könyvtár, lecseréli?</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="212"/>
        <location filename="../3rdparty/interface/queries.cpp" line="226"/>
        <source>Apply to all</source>
        <translation>Alkalmazás az összesre</translation>
    </message>
</context>
<context>
    <name>SettingDialog</name>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="166"/>
        <location filename="../src/source/dialog/settingdialog.cpp" line="195"/>
        <source>Current directory</source>
        <translation>Jelenlegi mappa</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="125"/>
        <source>Clear All</source>
        <translation>Összes elvetése</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="124"/>
        <source>Select All</source>
        <comment>button</comment>
        <translation>Összes kijelölése</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="126"/>
        <source>Recommended</source>
        <translation>Javasolt</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="160"/>
        <source>Extract archives to</source>
        <translation>Archívumok kicsomagolása ide</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="166"/>
        <location filename="../src/source/dialog/settingdialog.cpp" line="205"/>
        <source>Other directory</source>
        <translation>Más mappa</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="166"/>
        <location filename="../src/source/dialog/settingdialog.cpp" line="200"/>
        <source>Desktop</source>
        <translation>Asztal</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="272"/>
        <source>Delete archives after extraction</source>
        <translation>Az archívumok törlése a kibontás után</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="278"/>
        <location filename="../src/source/dialog/settingdialog.cpp" line="299"/>
        <source>Never</source>
        <translation>Soha</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="278"/>
        <location filename="../src/source/dialog/settingdialog.cpp" line="302"/>
        <source>Ask for confirmation</source>
        <translation>Kérjen megerősítést</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="278"/>
        <location filename="../src/source/dialog/settingdialog.cpp" line="305"/>
        <source>Always</source>
        <translation>Mindig</translation>
    </message>
</context>
<context>
    <name>SuccessPage</name>
    <message>
        <location filename="../src/source/page/successpage.cpp" line="79"/>
        <source>Compression successful</source>
        <translation>A tömörítés sikeres</translation>
    </message>
    <message>
        <location filename="../src/source/page/successpage.cpp" line="89"/>
        <source>View</source>
        <translation>Megtekintés</translation>
    </message>
    <message>
        <location filename="../src/source/page/successpage.cpp" line="92"/>
        <source>Back</source>
        <translation>Vissza</translation>
    </message>
</context>
<context>
    <name>UnCompressPage</name>
    <message>
        <location filename="../src/source/page/uncompresspage.cpp" line="75"/>
        <location filename="../src/source/page/uncompresspage.cpp" line="87"/>
        <location filename="../src/source/page/uncompresspage.cpp" line="116"/>
        <source>Extract to:</source>
        <translation>Kicsomagolás ide:</translation>
    </message>
    <message>
        <location filename="../src/source/page/uncompresspage.cpp" line="117"/>
        <source>Extract</source>
        <comment>button</comment>
        <translation>Kicsomagolás</translation>
    </message>
    <message>
        <location filename="../src/source/page/uncompresspage.cpp" line="191"/>
        <source>The default extraction path does not exist, please retry</source>
        <translation>Az alapértelmezett kicsomagolási útvonal nem létezik, kérjük próbálja újra</translation>
    </message>
    <message>
        <location filename="../src/source/page/uncompresspage.cpp" line="193"/>
        <source>You do not have permission to save files here, please change and retry</source>
        <translation>Nincs engedélye fájlok ide mentésére, kérjük, módosítsa és próbálja újra</translation>
    </message>
    <message>
        <location filename="../src/source/page/uncompresspage.cpp" line="197"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/source/page/uncompresspage.cpp" line="211"/>
        <source>Find directory</source>
        <translation>Mappa keresése</translation>
    </message>
</context>
<context>
    <name>UnCompressView</name>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="392"/>
        <source>You cannot add the archive to itself</source>
        <translation>Az archívum nem adható hozzá önmagához</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="392"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="618"/>
        <source>Extract</source>
        <comment>提取</comment>
        <translation>Kicsomagolás</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="620"/>
        <source>Extract to current directory</source>
        <translation>Kicsomagolás az aktuális mappába</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="622"/>
        <source>Open</source>
        <translation>Megnyitás</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="625"/>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="632"/>
        <source>Open with</source>
        <translation>Megnyitás ezzel</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="636"/>
        <location filename="../src/source/tree/uncompressview.cpp" line="737"/>
        <source>Select default program</source>
        <translation>Alapértelmezett program választása</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="687"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Mégsem</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="687"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Megerősítés</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="687"/>
        <source>Do you want to delete the selected file(s)?</source>
        <translation>Törli a kijelölt fájl(oka)t?</translation>
    </message>
</context>
</TS>
